/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

/// 
#[derive(Clone, Copy, Debug, Eq, PartialEq, Ord, PartialOrd, Hash, Serialize, Deserialize)]
pub enum RentalPropulsionType {
    #[serde(rename = "HUMAN")]
    Human,
    #[serde(rename = "ELECTRIC_ASSIST")]
    ElectricAssist,
    #[serde(rename = "ELECTRIC")]
    Electric,
    #[serde(rename = "COMBUSTION")]
    Combustion,
    #[serde(rename = "COMBUSTION_DIESEL")]
    CombustionDiesel,
    #[serde(rename = "HYBRID")]
    Hybrid,
    #[serde(rename = "PLUG_IN_HYBRID")]
    PlugInHybrid,
    #[serde(rename = "HYDROGEN_FUEL_CELL")]
    HydrogenFuelCell,

}

impl std::fmt::Display for RentalPropulsionType {
    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
        match self {
            Self::Human => write!(f, "HUMAN"),
            Self::ElectricAssist => write!(f, "ELECTRIC_ASSIST"),
            Self::Electric => write!(f, "ELECTRIC"),
            Self::Combustion => write!(f, "COMBUSTION"),
            Self::CombustionDiesel => write!(f, "COMBUSTION_DIESEL"),
            Self::Hybrid => write!(f, "HYBRID"),
            Self::PlugInHybrid => write!(f, "PLUG_IN_HYBRID"),
            Self::HydrogenFuelCell => write!(f, "HYDROGEN_FUEL_CELL"),
        }
    }
}

impl Default for RentalPropulsionType {
    fn default() -> RentalPropulsionType {
        Self::Human
    }
}

