/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

/// PedestrianProfile : Different accessibility profiles for pedestrians.
/// Different accessibility profiles for pedestrians.
#[derive(Clone, Copy, Debug, Eq, PartialEq, Ord, PartialOrd, Hash, Serialize, Deserialize)]
pub enum PedestrianProfile {
    #[serde(rename = "FOOT")]
    Foot,
    #[serde(rename = "WHEELCHAIR")]
    Wheelchair,

}

impl std::fmt::Display for PedestrianProfile {
    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
        match self {
            Self::Foot => write!(f, "FOOT"),
            Self::Wheelchair => write!(f, "WHEELCHAIR"),
        }
    }
}

impl Default for PedestrianProfile {
    fn default() -> PedestrianProfile {
        Self::Foot
    }
}

