/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

/// TripInfo : trip id and name
#[derive(Clone, Default, Debug, PartialEq, Serialize, Deserialize)]
pub struct TripInfo {
    /// trip ID (dataset trip id prefixed with the dataset tag)
    #[serde(rename = "tripId")]
    pub trip_id: String,
    /// trip display name
    #[serde(rename = "routeShortName")]
    pub route_short_name: String,
}

impl TripInfo {
    /// trip id and name
    pub fn new(trip_id: String, route_short_name: String) -> TripInfo {
        TripInfo {
            trip_id,
            route_short_name,
        }
    }
}

