/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

#[derive(Clone, Default, Debug, PartialEq, Serialize, Deserialize)]
pub struct EncodedPolyline {
    /// The encoded points of the polyline using the Google polyline encoding with precision 7.
    #[serde(rename = "points")]
    pub points: String,
    /// The number of points in the string
    #[serde(rename = "length")]
    pub length: i32,
}

impl EncodedPolyline {
    pub fn new(points: String, length: i32) -> EncodedPolyline {
        EncodedPolyline {
            points,
            length,
        }
    }
}

