/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

/// VertexType : - `NORMAL` - latitude / longitude coordinate or address - `BIKESHARE` - bike sharing station - `TRANSIT` - transit stop 
/// - `NORMAL` - latitude / longitude coordinate or address - `BIKESHARE` - bike sharing station - `TRANSIT` - transit stop 
#[derive(Clone, Copy, Debug, Eq, PartialEq, Ord, PartialOrd, Hash, Serialize, Deserialize)]
pub enum VertexType {
    #[serde(rename = "NORMAL")]
    Normal,
    #[serde(rename = "BIKESHARE")]
    Bikeshare,
    #[serde(rename = "TRANSIT")]
    Transit,

}

impl std::fmt::Display for VertexType {
    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
        match self {
            Self::Normal => write!(f, "NORMAL"),
            Self::Bikeshare => write!(f, "BIKESHARE"),
            Self::Transit => write!(f, "TRANSIT"),
        }
    }
}

impl Default for VertexType {
    fn default() -> VertexType {
        Self::Normal
    }
}

