/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

#[derive(Clone, Default, Debug, PartialEq, Serialize, Deserialize)]
pub struct Stoptimes200Response {
    /// list of stop times
    #[serde(rename = "stopTimes")]
    pub stop_times: Vec<models::StopTime>,
    /// Use the cursor to get the previous page of results. Insert the cursor into the request and post it to get the previous page. The previous page is a set of stop times BEFORE the first stop time in the result. 
    #[serde(rename = "previousPageCursor")]
    pub previous_page_cursor: String,
    /// Use the cursor to get the next page of results. Insert the cursor into the request and post it to get the next page. The next page is a set of stop times AFTER the last stop time in this result. 
    #[serde(rename = "nextPageCursor")]
    pub next_page_cursor: String,
}

impl Stoptimes200Response {
    pub fn new(stop_times: Vec<models::StopTime>, previous_page_cursor: String, next_page_cursor: String) -> Stoptimes200Response {
        Stoptimes200Response {
            stop_times,
            previous_page_cursor,
            next_page_cursor,
        }
    }
}

