/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

/// 
#[derive(Clone, Copy, Debug, Eq, PartialEq, Ord, PartialOrd, Hash, Serialize, Deserialize)]
pub enum RentalReturnConstraint {
    #[serde(rename = "NONE")]
    None,
    #[serde(rename = "ANY_STATION")]
    AnyStation,
    #[serde(rename = "ROUNDTRIP_STATION")]
    RoundtripStation,

}

impl std::fmt::Display for RentalReturnConstraint {
    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
        match self {
            Self::None => write!(f, "NONE"),
            Self::AnyStation => write!(f, "ANY_STATION"),
            Self::RoundtripStation => write!(f, "ROUNDTRIP_STATION"),
        }
    }
}

impl Default for RentalReturnConstraint {
    fn default() -> RentalReturnConstraint {
        Self::None
    }
}

