/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

#[derive(Clone, Default, Debug, PartialEq, Serialize, Deserialize)]
pub struct Initial200Response {
    /// latitude
    #[serde(rename = "lat")]
    pub lat: f64,
    /// longitude
    #[serde(rename = "lon")]
    pub lon: f64,
    /// zoom level
    #[serde(rename = "zoom")]
    pub zoom: f64,
}

impl Initial200Response {
    pub fn new(lat: f64, lon: f64, zoom: f64) -> Initial200Response {
        Initial200Response {
            lat,
            lon,
            zoom,
        }
    }
}

